spacepy.toolbox.rad2mlt — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »

# spacepy.toolbox.rad2mlt

`spacepy.toolbox.` `rad2mlt`(rad, midnight=False)

  Convert radians values to mlt transform radians from -pi to pi to mlt referenced from noon by default

  Parameters: | rad : numpy array array of radian values midnight : boolean (optional) reference to midnight instead of noon
  Returns: | out : numpy array array of mlt values

  See also

  `mlt2rad`

  Examples

      >>> rad2mlt(array([0,pi, pi/2.]))
      array([ 12.,  24.,  18.])

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »